==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicScrollBarUI__24ScrollListener.h <==
// public class javax.swing.plaf.basic.BasicScrollBarUI$ScrollListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4e9e112879e8ae4a javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener_H_
#define _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vmethods	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtable	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$_init$5dc65915419aac46(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$_init$e74d76b46404aaa2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object *, jint, jboolean);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, struct _jc_java_awt_event_ActionEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$setDirection$85545d6389fea7b0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, jint);
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$setScrollByBlock$ed802290e853b212(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method_info$actionPerformed$9046a9754e643ffd;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method_info$setDirection$85545d6389fea7b0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method_info$setScrollByBlock$ed802290e853b212;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, struct _jc_java_awt_event_ActionEvent$object *);
	void	(*setDirection$85545d6389fea7b0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, jint);
	void	(*setScrollByBlock$ed802290e853b212)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, jboolean);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vmethods	javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$refs {
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_refs	javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_nonrefs {
	jint	direction;
	jboolean	block;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_nonrefs	javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object {
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicScrollBarUI__24ScrollListener.h <==
// public class javax.swing.plaf.basic.BasicScrollBarUI$ScrollListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a3ce638f1c92884e javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener_H_
#define _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vmethods	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtable	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$_init$5dc65915419aac46(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$_init$e74d76b46404aaa2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object *, jint, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$setDirection$85545d6389fea7b0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method$setScrollByBlock$ed802290e853b212(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method_info$actionPerformed$9046a9754e643ffd;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method_info$setDirection$85545d6389fea7b0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$method_info$setScrollByBlock$ed802290e853b212;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
	void	(*setDirection$85545d6389fea7b0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, jint) _JC_JCNI_ATTR;
	void	(*setScrollByBlock$ed802290e853b212)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vmethods	javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$refs {
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_refs	javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_nonrefs {
	jint	direction;
	jboolean	block;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$sub_nonrefs	javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$object {
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$vtype _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ScrollListener_H_ */
